@@ -17,27 +17,29 @@ class CodeMirrorWidget(forms.Textarea):
     """
     Widget to add a CodeMirror or DjangoCodeMirror instance on a textarea
     
-    Accept two suplementary optionnal arguments :
+    Take the same arguments than ``forms.Textarea`` and accepts three suplementary 
+    optionnal arguments :
     
     * ``codemirror_attrs`` receive a dict with settings for the instance (CodeMirror 
       or DjangoCodeMirror);
     * ``codemirror_only`` to disable DjangoCodeMirror and use directly CodeMirror. By 
-      default DjangoCodeMirror is always used.
-    * ``embed_settings`` to disable embedding of Javascript settings in the widget HTML, 
-      you will have to load them manually;
-    
-    Recoit le même argument optionnel ``attr`` que le widget ``forms.Textarea`` plus un 
-    autre argument optionnel ``codemirror_attrs`` qui est un dictionnaire des options 
-    de l'instance CodeMirror
+      default DjangoCodeMirror is always used;
+    * ``embed_settings`` a boolean to active the automatic embed of the needed 
+      Javascript code to launch a CodeMirror instance for the field. This is ``False`` 
+      by default because there is lots of possible scenarios to manage your assets and 
+      Javascript code. So if you active this, DjangoCodeMirror assets must be loaded 
+      BEFORE your field appear in the HTML code;
     """
     def __init__(self, attrs=None, codemirror_attrs=None, codemirror_only=False, embed_settings=False):
         self.codemirror_attrs = codemirror_attrs or {}
         self.codemirror_only = codemirror_only
         self.embed_settings = embed_settings
-        self._codemirror_final_settings_cache = None
+        self._field_settings_cache = None
+        
         default_attrs = {'cols': '40', 'rows': '10'}
         if attrs:
             default_attrs.update(attrs)
+            
         super(CodeMirrorWidget, self).__init__(default_attrs)
 
     def render(self, name, value, attrs=None):
@@ -45,22 +47,25 @@ class CodeMirrorWidget(forms.Textarea):
         final_attrs = self.build_attrs(attrs, name=name)
         assert 'id' in final_attrs, "CodeMirror widget attributes must contain 'id'"
         
+        field_settings = self._get_codemirror_settings(final_attrs)
+        
         html = [u'<textarea%s>%s</textarea>' % (flatatt(final_attrs), escape(value))]
-        self._codemirror_final_settings_cache = self._get_codemirror_settings(final_attrs)
         if self.embed_settings:
-            html.append(self._codemirror_final_settings_cache)
+            html.append(self._build_codemirror_settings(final_attrs, field_settings))
         return mark_safe(u'\n'.join(html))
 
     def _get_codemirror_settings(self, final_attrs):
-        settings = self._reverse_setting_urls( self.codemirror_attrs )
+        if self._field_settings_cache is None:
+            self._field_settings_cache = self._reverse_setting_urls( self.codemirror_attrs )
+        return self._field_settings_cache
+
+    def _build_codemirror_settings(self, final_attrs, field_settings):
         html = settings_local.DJANGOCODEMIRROR_FIELD_INIT_JS
         if self.codemirror_only:
             html = settings_local.CODEMIRROR_FIELD_INIT_JS
-        if self.embed_settings:
-            return html.format(inputid=final_attrs['id'], settings=json.dumps(settings))
-        return settings
+        return html.format(inputid=final_attrs['id'], settings=json.dumps(field_settings))
 
-    def _reverse_setting_urls(self, settings):
+    def _reverse_setting_urls(self, field_settings):
         """
         Reverse urls with args and kwargs from a tuple ``(urlname, args, kwargs)``, 
         items than are strings are not reversed.
@@ -68,16 +73,16 @@ class CodeMirrorWidget(forms.Textarea):
         This is only working on setting items : preview_url, help_link, quicksave_url
         """
         for name in ['preview_url', 'help_link', 'quicksave_url', 'settings_url']:
-            if name in settings and not isinstance(settings.get(name, ''), basestring):
+            if name in field_settings and not isinstance(field_settings.get(name, ''), basestring):
                 args = []
                 kwargs = {}
-                urlname = settings[name][0]
-                if len(settings[name])>1:
-                    args = settings[name][1]
-                    if len(settings[name])>2:
-                        kwargs = settings[name][2]
-                settings[name] = reverse(urlname, args=args, kwargs=kwargs)
-        return settings
+                urlname = field_settings[name][0]
+                if len(field_settings[name])>1:
+                    args = field_settings[name][1]
+                    if len(field_settings[name])>2:
+                        kwargs = field_settings[name][2]
+                field_settings[name] = reverse(urlname, args=args, kwargs=kwargs)
+        return field_settings
     
     def _media(self):
         """
