@@ -83,7 +83,7 @@ var methods = {
                 }
             }
             
-            var input_source = $(this), // allway the input source from where is created djangocodemirror
+            var input_source = $(this), // this is allways the input source from where is created djangocodemirror
                 djangocodemirror_key = "djangocodemirror-id-" + (input_source.attr('id')||'default'), // djangocodemirror instance ID
                 container = $("<div class=\"DjangoCodeMirror\"></div>"),
                 header = $("<div class=\"DjangoCodeMirror_menu\"><ul></ul><div class=\"cale\"></div></div>"),
@@ -109,21 +109,22 @@ var methods = {
                 }
             }
             
-            // Update settings to append the cursor activy function
-            settings["onCursorActivity"] = function() { events.cursor_activity(input_source) };
-            
             // Build CodeMirror
             var codemirror_instance = CodeMirror.fromTextArea(this, settings);
-            // Force options in codemirror that it doesn't know of
+            // Force some certain key biding
             codemirror_instance.setOption('extraKeys', {
                 "Tab": "indentMore", 
                 "Shift-Tab": "indentLess",
-                // WARNING: Ctrl/Cmd prefix should be determined from the enabled default 
-                //       keymap (because on MacOS it should be Cmd and not Ctrl)
-                "Ctrl-S": function(cm){ cm.save(); $('.buttonQuickSave').trigger('click'); }
-                // NOTE: Here should be defined syntax button keybinding from there key attribute
+                // Quicksave keybind should be done along with the rest of buttons, not here
+                "Ctrl-S": function(cm){ cm.save(); $('.buttonQuickSave').trigger('click'); },
+                "Cmd-S": function(cm){ cm.save(); $('.buttonQuickSave').trigger('click'); }
             });
             
+            // Enable the cursor activy function
+            codemirror_instance.on("cursorActivity", function(cm) {
+                events.cursor_activity(input_source);
+            });
+
             // Attach element's data
             input_source.data("djangocodemirror", {
                 "key" : djangocodemirror_key,
@@ -153,7 +154,7 @@ var methods = {
             
             // Default active line
             if(settings.enable_active_line){
-                input_source.data("codemirror_hlLine", codemirror_instance.setLineClass(0, "activeline"));
+                input_source.data("codemirror_hlLine", codemirror_instance.addLineClass(0, "background", "activeline"));
             }
             
             // Refresh update of CodeMirror
@@ -214,8 +215,7 @@ var events = {
             cur = instance_data.codemirror.getCursor();
         // Reset previous highlighted lines
         if(instance_data.settings.enable_active_line){
-            var hlLine = input_source.data("codemirror_hlLine");
-            instance_data.codemirror.setLineClass(hlLine, null);
+            instance_data.codemirror.removeLineClass(input_source.data("codemirror_hlLine"), "background", "activeline");
         }
         // Update column and row counters
         $(".DjangoCodeMirror_tabs .cursor_pos span.line", instance_data.container).html((cur.line+1));
@@ -234,7 +234,7 @@ var events = {
         }
         // Update the highlight
         if(instance_data.settings.enable_active_line){
-            input_source.data("codemirror_hlLine", instance_data.codemirror.setLineClass(cur.line, "activeline"));
+            input_source.data("codemirror_hlLine", instance_data.codemirror.addLineClass(cur.line, "background", "activeline"));
         }
     },
     /*
@@ -328,7 +328,7 @@ var events = {
         var old_place_scene = $('<div>').attr('id', "DjangoCodeMirror_old_place");
         
         // Save initial editor size to restore after exiting the maximized mode
-        $(".CodeMirror-scroll", instance_data.container).data('original_size', $(".CodeMirror-scroll", instance_data.container).height());
+        $(".CodeMirror", instance_data.container).data('original_size', $(".CodeMirror", instance_data.container).height());
         
         // Catch and use the ESC key to exit from the maximized mode
         $(scene).keydown( function(e){
@@ -351,7 +351,7 @@ var events = {
         scene.css(elems_css[0]).attr('id', "DjangoCodeMirror_fullscreen_scene");
         instance_data.container.css("width", "100%");
         // Met la hauteur de CodeMirror à la dimension qui lui est disponible
-        $(".CodeMirror-scroll", instance_data.container).css(elems_css[1]);
+        $(".CodeMirror", instance_data.container).css(elems_css[1]);
         events.hide_preview(event);
         // Recalcul auto de CodeMirror
         instance_data.codemirror.refresh();
@@ -383,9 +383,9 @@ var events = {
         
         // Restitue les dimensions originals
         instance_data.container.css("width", '');
-        $(".CodeMirror-scroll", instance_data.container).css(
+        $(".CodeMirror", instance_data.container).css(
             "height",
-            $(".CodeMirror-scroll", instance_data.container).data('original_size') + "px"
+            $(".CodeMirror", instance_data.container).data('original_size') + "px"
         );
         events.hide_preview(event);
         $(window).unbind("resize.djc_maximize");
@@ -396,7 +396,7 @@ var events = {
             instance_data = input_source.data("djangocodemirror"),
             elems_css = coreutils.get_fullscreen_sizes(input_source);
         $("#DjangoCodeMirror_fullscreen_scene").css(elems_css[0]);
-        $(".CodeMirror-scroll", instance_data.container).css(elems_css[1]);
+        $(".CodeMirror", instance_data.container).css(elems_css[1]);
         instance_data.codemirror.refresh();
     },
     
@@ -515,7 +515,7 @@ var events = {
             instance_data = input_source.data("djangocodemirror"),
             preview_id = instance_data.container.data("DCM_preview_markid"),
             elems_css = coreutils.get_preview_sizes(input_source),
-            editor_container = $(".CodeMirror-scroll", instance_data.container);
+            editor_container = $(".CodeMirror", instance_data.container);
         $("#"+preview_id).css(elems_css[0]);
         $("#"+preview_id+" .PreviewContent").css(elems_css[1]);
         instance_data.codemirror.refresh();
@@ -598,10 +598,11 @@ var events = {
         return false;
     },
     resize_settings: function(event) {
+        // Far from perfect, essentially because the borders are not really computed
         var input_source = $(event.data.input_source),
             instance_data = input_source.data("djangocodemirror");
             panel = $(event.data.panel),
-            borders = 0;
+            borders = 2;
         panel.css({
             "width": (instance_data.container.outerWidth()-borders)+"px",
             "height": (instance_data.container.outerHeight()-borders)+"px"
@@ -692,18 +693,21 @@ var coreutils = {
     */
     get_preview_sizes: function(input_source) {
         var instance_data = input_source.data("djangocodemirror"),
-            editor_container = $(".CodeMirror-scroll", instance_data.container),
+            editor_container = $(".CodeMirror", instance_data.container),
             editor_scrollbar = $(".CodeMirror-scrollbar", instance_data.container),
             menu_height = $(".DjangoCodeMirror_menu", instance_data.container).outerHeight(true),
-            scrollbar_plus = (editor_scrollbar.css('display') == 'block') ? editor_scrollbar.outerWidth() : 0;
+            // TODO: These ones are for a dirty little hack on the top position, there should be 
+            //       a better way, at least a more flexible
+            fullscreen_enabled = ($("#DjangoCodeMirror_fullscreen_scene").length>0) ? true : false,
+            pos_top_border = (fullscreen_enabled) ? 0 : 1;
         
         var scene_css = {
             'position': "absolute",
             'z-index': 3000,
             'left': editor_container.offset().left,
-            'top': editor_container.offset().top-menu_height,
-            'width': (editor_container.outerWidth()+scrollbar_plus)-(instance_data.settings.preview_padding*2)-(instance_data.settings.preview_borders*2),
-            'height': editor_container.outerHeight()-(instance_data.settings.preview_padding*2)+menu_height-(instance_data.settings.preview_borders*2),
+            'top': editor_container.offset().top-menu_height+pos_top_border,
+            'width': editor_container.outerWidth()-(instance_data.settings.preview_borders*2),
+            'height': editor_container.outerHeight()+menu_height-(instance_data.settings.preview_borders*2),
             'overflow': 'auto',
             'padding': instance_data.settings.preview_padding
         };
